@@ -8,8 +8,8 @@
  * 
  */
 
-#ifndef INC__VERBOSE_HPP
-#define INC__VERBOSE_HPP
+#ifndef INC_SRT_VERBOSE_HPP
+#define INC_SRT_VERBOSE_HPP
 
 #include <iostream>
 #if SRT_ENABLE_VERBOSE_LOCK
@@ -29,18 +29,15 @@ struct LogLock { LogLock() {} };
 
 class Log
 {
-    bool noeol;
+    bool noeol = false;
 #if SRT_ENABLE_VERBOSE_LOCK
-    bool lockline;
+    bool lockline = false;
 #endif
-public:
 
-    Log():
-        noeol(false)
-#if SRT_ENABLE_VERBOSE_LOCK
-        ,lockline(false)
-#endif
-    {}
+    // Disallow creating dynamic objects
+    void* operator new(size_t);
+
+public:
 
     template <class V>
     Log& operator<<(const V& arg)
@@ -59,9 +56,46 @@ public:
     ~Log();
 };
 
+
+class ErrLog: public Log
+{
+public:
+
+    template <class V>
+    ErrLog& operator<<(const V& arg)
+    {
+        // Template - must be here; extern template requires
+        // predefined specializations.
+        if (on)
+            (*cverb) << arg;
+        else
+            std::cerr << arg;
+        return *this;
+    }
+};
+
+// terminal
+inline void Print(Log& ) {}
+
+template <typename Arg1, typename... Args>
+inline void Print(Log& out, Arg1&& arg1, Args&&... args)
+{
+    out << arg1;
+    Print(out, args...);
+}
+
 }
 
 inline Verbose::Log Verb() { return Verbose::Log(); }
+inline Verbose::ErrLog Verror() { return Verbose::ErrLog(); }
+
+template <typename... Args>
+inline void Verb(Args&&... args)
+{
+    Verbose::Log log;
+    Verbose::Print(log, args...);
+}
+
 
 // Manipulator tags
 static const Verbose::LogNoEol VerbNoEOL;
