@@ -68,7 +68,7 @@ using srt_logging::qslog;
 
 using namespace srt::sync;
 
-CSndLossList::CSndLossList(int size)
+srt::CSndLossList::CSndLossList(int size)
     : m_caSeq()
     , m_iHead(-1)
     , m_iLength(0)
@@ -89,13 +89,13 @@ CSndLossList::CSndLossList(int size)
     setupMutex(m_ListLock, "LossList");
 }
 
-CSndLossList::~CSndLossList()
+srt::CSndLossList::~CSndLossList()
 {
     delete[] m_caSeq;
     releaseMutex(m_ListLock);
 }
 
-void CSndLossList::traceState() const
+void srt::CSndLossList::traceState() const
 {
     int pos = m_iHead;
     while (pos != SRT_SEQNO_NONE)
@@ -109,7 +109,7 @@ void CSndLossList::traceState() const
     std::cout << "\n";
 }
 
-int CSndLossList::insert(int32_t seqno1, int32_t seqno2)
+int srt::CSndLossList::insert(int32_t seqno1, int32_t seqno2)
 {
     if (seqno1 < 0 || seqno2 < 0 ) {
         LOGC(qslog.Error, log << "IPE: Tried to insert negative seqno " << seqno1 << ":" << seqno2
@@ -226,7 +226,7 @@ int CSndLossList::insert(int32_t seqno1, int32_t seqno2)
     return m_iLength - origlen;
 }
 
-void CSndLossList::removeUpTo(int32_t seqno)
+void srt::CSndLossList::removeUpTo(int32_t seqno)
 {
     ScopedLock listguard(m_ListLock);
 
@@ -338,14 +338,14 @@ void CSndLossList::removeUpTo(int32_t seqno)
     }
 }
 
-int CSndLossList::getLossLength() const
+int srt::CSndLossList::getLossLength() const
 {
     ScopedLock listguard(m_ListLock);
 
     return m_iLength;
 }
 
-int32_t CSndLossList::popLostSeq()
+int32_t srt::CSndLossList::popLostSeq()
 {
     ScopedLock listguard(m_ListLock);
 
@@ -389,7 +389,7 @@ int32_t CSndLossList::popLostSeq()
     return seqno;
 }
 
-void CSndLossList::insertHead(int pos, int32_t seqno1, int32_t seqno2)
+void srt::CSndLossList::insertHead(int pos, int32_t seqno1, int32_t seqno2)
 {
     SRT_ASSERT(pos >= 0);
     m_caSeq[pos].seqstart = seqno1;
@@ -405,7 +405,7 @@ void CSndLossList::insertHead(int pos, int32_t seqno1, int32_t seqno2)
     m_iLength += CSeqNo::seqlen(seqno1, seqno2);
 }
 
-void CSndLossList::insertAfter(int pos, int pos_after, int32_t seqno1, int32_t seqno2)
+void srt::CSndLossList::insertAfter(int pos, int pos_after, int32_t seqno1, int32_t seqno2)
 {
     m_caSeq[pos].seqstart = seqno1;
     SRT_ASSERT(m_caSeq[pos].seqend == SRT_SEQNO_NONE);
@@ -419,7 +419,7 @@ void CSndLossList::insertAfter(int pos, int pos_after, int32_t seqno1, int32_t s
     m_iLength += CSeqNo::seqlen(seqno1, seqno2);
 }
 
-void CSndLossList::coalesce(int loc)
+void srt::CSndLossList::coalesce(int loc)
 {
     // coalesce with next node. E.g., [3, 7], ..., [6, 9] becomes [3, 9]
     while ((m_caSeq[loc].inext != -1) && (m_caSeq[loc].seqend != SRT_SEQNO_NONE))
@@ -455,7 +455,7 @@ void CSndLossList::coalesce(int loc)
     }
 }
 
-bool CSndLossList::updateElement(int pos, int32_t seqno1, int32_t seqno2)
+bool srt::CSndLossList::updateElement(int pos, int32_t seqno1, int32_t seqno2)
 {
     m_iLastInsertPos = pos;
 
@@ -481,12 +481,13 @@ bool CSndLossList::updateElement(int pos, int32_t seqno1, int32_t seqno2)
 
 ////////////////////////////////////////////////////////////////////////////////
 
-CRcvLossList::CRcvLossList(int size)
+srt::CRcvLossList::CRcvLossList(int size)
     : m_caSeq()
     , m_iHead(-1)
     , m_iTail(-1)
     , m_iLength(0)
     , m_iSize(size)
+    , m_iLargestSeq(SRT_SEQNO_NONE)
 {
     m_caSeq = new Seq[m_iSize];
 
@@ -498,15 +499,33 @@ CRcvLossList::CRcvLossList(int size)
     }
 }
 
-CRcvLossList::~CRcvLossList()
+srt::CRcvLossList::~CRcvLossList()
 {
     delete[] m_caSeq;
 }
 
-void CRcvLossList::insert(int32_t seqno1, int32_t seqno2)
+void srt::CRcvLossList::insert(int32_t seqno1, int32_t seqno2)
 {
     // Data to be inserted must be larger than all those in the list
-    // guaranteed by the UDT receiver
+    if (m_iLargestSeq != SRT_SEQNO_NONE && CSeqNo::seqcmp(seqno1, m_iLargestSeq) <= 0)
+    {
+        if (CSeqNo::seqcmp(seqno2, m_iLargestSeq) > 0)
+        {
+            LOGC(qrlog.Warn,
+                 log << "RCV-LOSS/insert: seqno1=" << seqno1 << " too small, adjust to "
+                     << CSeqNo::incseq(m_iLargestSeq));
+            seqno1 = CSeqNo::incseq(m_iLargestSeq);
+        }
+        else
+        {
+            LOGC(qrlog.Warn,
+                 log << "RCV-LOSS/insert: (" << seqno1 << "," << seqno2
+                     << ") to be inserted is too small: m_iLargestSeq=" << m_iLargestSeq << ", m_iLength=" << m_iLength
+                     << ", m_iHead=" << m_iHead << ", m_iTail=" << m_iTail << " -- REJECTING");
+            return;
+        }
+    }
+    m_iLargestSeq = seqno2;
 
     if (0 == m_iLength)
     {
@@ -559,8 +578,11 @@ void CRcvLossList::insert(int32_t seqno1, int32_t seqno2)
     m_iLength += CSeqNo::seqlen(seqno1, seqno2);
 }
 
-bool CRcvLossList::remove(int32_t seqno)
+bool srt::CRcvLossList::remove(int32_t seqno)
 {
+    if (m_iLargestSeq == SRT_SEQNO_NONE || CSeqNo::seqcmp(seqno, m_iLargestSeq) > 0)
+        m_iLargestSeq = seqno;
+
     if (0 == m_iLength)
         return false;
 
@@ -583,6 +605,8 @@ bool CRcvLossList::remove(int32_t seqno)
                 m_iHead = m_caSeq[m_iHead].inext;
                 if (-1 != m_iHead)
                     m_caSeq[m_iHead].iprior = -1;
+                else
+                    m_iTail = -1;
             }
             else
             {
@@ -689,7 +713,7 @@ bool CRcvLossList::remove(int32_t seqno)
     return true;
 }
 
-bool CRcvLossList::remove(int32_t seqno1, int32_t seqno2)
+bool srt::CRcvLossList::remove(int32_t seqno1, int32_t seqno2)
 {
     if (seqno1 <= seqno2)
     {
@@ -707,7 +731,7 @@ bool CRcvLossList::remove(int32_t seqno1, int32_t seqno2)
     return true;
 }
 
-bool CRcvLossList::find(int32_t seqno1, int32_t seqno2) const
+bool srt::CRcvLossList::find(int32_t seqno1, int32_t seqno2) const
 {
     if (0 == m_iLength)
         return false;
@@ -728,12 +752,12 @@ bool CRcvLossList::find(int32_t seqno1, int32_t seqno2) const
     return false;
 }
 
-int CRcvLossList::getLossLength() const
+int srt::CRcvLossList::getLossLength() const
 {
     return m_iLength;
 }
 
-int32_t CRcvLossList::getFirstLostSeq() const
+int32_t srt::CRcvLossList::getFirstLostSeq() const
 {
     if (0 == m_iLength)
         return SRT_SEQNO_NONE;
@@ -741,7 +765,7 @@ int32_t CRcvLossList::getFirstLostSeq() const
     return m_caSeq[m_iHead].seqstart;
 }
 
-void CRcvLossList::getLossArray(int32_t* array, int& len, int limit)
+void srt::CRcvLossList::getLossArray(int32_t* array, int& len, int limit)
 {
     len = 0;
 
@@ -764,7 +788,7 @@ void CRcvLossList::getLossArray(int32_t* array, int& len, int limit)
     }
 }
 
-CRcvFreshLoss::CRcvFreshLoss(int32_t seqlo, int32_t seqhi, int initial_age)
+srt::CRcvFreshLoss::CRcvFreshLoss(int32_t seqlo, int32_t seqhi, int initial_age)
     : ttl(initial_age)
     , timestamp(steady_clock::now())
 {
@@ -772,7 +796,7 @@ CRcvFreshLoss::CRcvFreshLoss(int32_t seqlo, int32_t seqhi, int initial_age)
     seq[1] = seqhi;
 }
 
-CRcvFreshLoss::Emod CRcvFreshLoss::revoke(int32_t sequence)
+srt::CRcvFreshLoss::Emod srt::CRcvFreshLoss::revoke(int32_t sequence)
 {
     int32_t diffbegin = CSeqNo::seqcmp(sequence, seq[0]);
     int32_t diffend   = CSeqNo::seqcmp(sequence, seq[1]);
@@ -803,7 +827,7 @@ CRcvFreshLoss::Emod CRcvFreshLoss::revoke(int32_t sequence)
     return SPLIT;
 }
 
-CRcvFreshLoss::Emod CRcvFreshLoss::revoke(int32_t lo, int32_t hi)
+srt::CRcvFreshLoss::Emod srt::CRcvFreshLoss::revoke(int32_t lo, int32_t hi)
 {
     // This should only if the range lo-hi is anyhow covered by seq[0]-seq[1].
 
