@@ -9,8 +9,8 @@
  */
 
 
-#ifndef INC__PACKETFILTER_BUILTIN_H
-#define INC__PACKETFILTER_BUILTIN_H
+#ifndef INC_SRT_PACKETFILTER_BUILTIN_H
+#define INC_SRT_PACKETFILTER_BUILTIN_H
 
 // Integration header
 #include "fec.h"
