@@ -52,6 +52,7 @@ written by
 #include "srt.h"
 #include "socketconfig.h"
 
+using namespace srt;
 extern const int32_t SRT_DEF_VERSION = SrtParseVersion(SRT_VERSION);
 
 namespace {
@@ -69,7 +70,7 @@ struct CSrtConfigSetter<SRTO_MSS>
     static void set(CSrtConfig& co, const void* optval, int optlen)
     {
         int ival = cast_optval<int>(optval, optlen);
-        if (ival < int(srt::CPacket::UDP_HDR_SIZE + CHandShake::m_iContentSize))
+        if (ival < int(CPacket::UDP_HDR_SIZE + CHandShake::m_iContentSize))
             throw CUDTException(MJ_NOTSUP, MN_INVAL, 0);
 
         co.iMSS = ival;
@@ -108,7 +109,7 @@ struct CSrtConfigSetter<SRTO_SNDBUF>
         if (bs <= 0)
             throw CUDTException(MJ_NOTSUP, MN_INVAL, 0);
 
-        co.iSndBufSize = bs / (co.iMSS - srt::CPacket::UDP_HDR_SIZE);
+        co.iSndBufSize = bs / (co.iMSS - CPacket::UDP_HDR_SIZE);
     }
 };
 
@@ -122,7 +123,7 @@ struct CSrtConfigSetter<SRTO_RCVBUF>
             throw CUDTException(MJ_NOTSUP, MN_INVAL, 0);
 
         // Mimimum recv buffer size is 32 packets
-        const int mssin_size = co.iMSS - srt::CPacket::UDP_HDR_SIZE;
+        const int mssin_size = co.iMSS - CPacket::UDP_HDR_SIZE;
 
         if (val > mssin_size * co.DEF_MIN_FLIGHT_PKT)
             co.iRcvBufSize = val / mssin_size;
@@ -263,7 +264,6 @@ struct CSrtConfigSetter<SRTO_BINDTODEVICE>
         using namespace srt_logging;
 #ifdef SRT_ENABLE_BINDTODEVICE
         using namespace std;
-        using namespace srt_logging;
 
         string val;
         if (optlen == -1)
@@ -502,7 +502,7 @@ struct CSrtConfigSetter<SRTO_CONNTIMEO>
         if (val < 0)
             throw CUDTException(MJ_NOTSUP, MN_INVAL, 0);
 
-        using namespace srt::sync;
+        using namespace sync;
         co.tdConnTimeOut = milliseconds_from(val);
     }
 };
@@ -570,7 +570,7 @@ struct CSrtConfigSetter<SRTO_CONGESTION>
         if (val == "vod")
             val = "file";
 
-        bool res = srt::SrtCongestion::exists(val);
+        bool res = SrtCongestion::exists(val);
         if (!res)
             throw CUDTException(MJ_NOTSUP, MN_INVAL, 0);
 
@@ -610,8 +610,8 @@ struct CSrtConfigSetter<SRTO_PAYLOADSIZE>
             // This means that the filter might have been installed before,
             // and the fix to the maximum payload size was already applied.
             // This needs to be checked now.
-            srt::SrtFilterConfig fc;
-            if (!srt::ParseFilterConfig(co.sPacketFilterConfig.str(), fc))
+            SrtFilterConfig fc;
+            if (!ParseFilterConfig(co.sPacketFilterConfig.str(), fc))
             {
                 // Break silently. This should not happen
                 LOGC(aclog.Error, log << "SRTO_PAYLOADSIZE: IPE: failing filter configuration installed");
@@ -690,7 +690,7 @@ struct CSrtConfigSetter<SRTO_TRANSTYPE>
     }
 };
 
-#if ENABLE_EXPERIMENTAL_BONDING
+#if ENABLE_BONDING
 template<>
 struct CSrtConfigSetter<SRTO_GROUPCONNECT>
 {
@@ -782,7 +782,7 @@ struct CSrtConfigSetter<SRTO_PEERIDLETIMEO>
         if (val < 0)
             throw CUDTException(MJ_NOTSUP, MN_INVAL, 0);
 
-        co.iPeerIdleTimeout = val;
+        co.iPeerIdleTimeout_ms = val;
     }
 };
 
@@ -803,9 +803,9 @@ struct CSrtConfigSetter<SRTO_PACKETFILTER>
         using namespace srt_logging;
         std::string arg((const char*)optval, optlen);
         // Parse the configuration string prematurely
-        srt::SrtFilterConfig fc;
-        srt::PacketFilter::Factory* fax = 0;
-        if (!srt::ParseFilterConfig(arg, (fc), (&fax)))
+        SrtFilterConfig fc;
+        PacketFilter::Factory* fax = 0;
+        if (!ParseFilterConfig(arg, (fc), (&fax)))
         {
             LOGC(aclog.Error,
                  log << "SRTO_PACKETFILTER: Incorrect syntax. Use: FILTERTYPE[,KEY:VALUE...]. "
@@ -833,9 +833,9 @@ struct CSrtConfigSetter<SRTO_PACKETFILTER>
     }
 };
 
-#if ENABLE_EXPERIMENTAL_BONDING
+#if ENABLE_BONDING
 template<>
-struct CSrtConfigSetter<SRTO_GROUPSTABTIMEO>
+struct CSrtConfigSetter<SRTO_GROUPMINSTABLETIMEO>
 {
     static void set(CSrtConfig& co, const void* optval, int optlen)
     {
@@ -843,25 +843,29 @@ struct CSrtConfigSetter<SRTO_GROUPSTABTIMEO>
         // This option is meaningless for the socket itself.
         // It's set here just for the sake of setting it on a listener
         // socket so that it is then applied on the group when a
-        // group connection is configuired.
-        const int val = cast_optval<int>(optval, optlen);
+        // group connection is configured.
+        const int val_ms = cast_optval<int>(optval, optlen);
+        const int min_timeo_ms = (int) CSrtConfig::COMM_DEF_MIN_STABILITY_TIMEOUT_MS;
 
-        // Search if you already have SRTO_PEERIDLETIMEO set
-
-        const int idletmo = co.iPeerIdleTimeout;
-
-        // Both are in milliseconds.
-        // This option is RECORDED in microseconds, while
-        // idletmo is recorded in milliseconds, only translated to
-        // microseconds directly before use.
-        if (val >= idletmo)
+        if (val_ms < min_timeo_ms)
         {
-            LOGC(aclog.Error, log << "group option: SRTO_GROUPSTABTIMEO(" << val
-                                  << ") exceeds SRTO_PEERIDLETIMEO(" << idletmo << ")");
+            LOGC(qmlog.Error,
+                log << "group option: SRTO_GROUPMINSTABLETIMEO min allowed value is "
+                    << min_timeo_ms << " ms.");
             throw CUDTException(MJ_NOTSUP, MN_INVAL, 0);
         }
 
-        co.uStabilityTimeout = val * 1000;
+        const int idletmo_ms = co.iPeerIdleTimeout_ms;
+
+        if (val_ms > idletmo_ms)
+        {
+            LOGC(aclog.Error, log << "group option: SRTO_GROUPMINSTABLETIMEO(" << val_ms
+                                  << ") exceeds SRTO_PEERIDLETIMEO(" << idletmo_ms << ")");
+            throw CUDTException(MJ_NOTSUP, MN_INVAL, 0);
+        }
+
+        co.uMinStabilityTimeout_ms = val_ms;
+        LOGC(smlog.Error, log << "SRTO_GROUPMINSTABLETIMEO set " << val_ms);
     }
 };
 #endif
@@ -925,8 +929,9 @@ int dispatchSet(SRT_SOCKOPT optName, CSrtConfig& co, const void* optval, int opt
         DISPATCH(SRTO_MESSAGEAPI);
         DISPATCH(SRTO_PAYLOADSIZE);
         DISPATCH(SRTO_TRANSTYPE);
-#if ENABLE_EXPERIMENTAL_BONDING
+#if ENABLE_BONDING
         DISPATCH(SRTO_GROUPCONNECT);
+        DISPATCH(SRTO_GROUPMINSTABLETIMEO);
 #endif
         DISPATCH(SRTO_KMREFRESHRATE);
         DISPATCH(SRTO_KMPREANNOUNCE);
@@ -934,9 +939,6 @@ int dispatchSet(SRT_SOCKOPT optName, CSrtConfig& co, const void* optval, int opt
         DISPATCH(SRTO_PEERIDLETIMEO);
         DISPATCH(SRTO_IPV6ONLY);
         DISPATCH(SRTO_PACKETFILTER);
-#if ENABLE_EXPERIMENTAL_BONDING
-        DISPATCH(SRTO_GROUPSTABTIMEO);
-#endif
         DISPATCH(SRTO_RETRANSMITALGO);
 
 #undef DISPATCH
@@ -952,7 +954,7 @@ int CSrtConfig::set(SRT_SOCKOPT optName, const void* optval, int optlen)
     return dispatchSet(optName, *this, optval, optlen);
 }
 
-#if ENABLE_EXPERIMENTAL_BONDING
+#if ENABLE_BONDING
 bool SRT_SocketOptionObject::add(SRT_SOCKOPT optname, const void* optval, size_t optlen)
 {
     // Check first if this option is allowed to be set
@@ -964,7 +966,7 @@ bool SRT_SocketOptionObject::add(SRT_SOCKOPT optname, const void* optval, size_t
     case SRTO_CONNTIMEO:
     case SRTO_DRIFTTRACER:
         //SRTO_FC - not allowed to be different among group members
-    case SRTO_GROUPSTABTIMEO:
+    case SRTO_GROUPMINSTABLETIMEO:
         //SRTO_INPUTBW - per transmission setting
     case SRTO_IPTOS:
     case SRTO_IPTTL:
