@@ -36,31 +36,20 @@ int srt_cleanup() { return CUDT::cleanup(); }
 SRTSOCKET srt_socket(int , int , int ) { return CUDT::socket(); }
 SRTSOCKET srt_create_socket() { return CUDT::socket(); }
 
-#if ENABLE_EXPERIMENTAL_BONDING
+#if ENABLE_BONDING
 // Group management.
 SRTSOCKET srt_create_group(SRT_GROUP_TYPE gt) { return CUDT::createGroup(gt); }
-int srt_include(SRTSOCKET socket, SRTSOCKET group) { return CUDT::addSocketToGroup(socket, group); }
-int srt_exclude(SRTSOCKET socket) { return CUDT::removeSocketFromGroup(socket); }
 SRTSOCKET srt_groupof(SRTSOCKET socket) { return CUDT::getGroupOfSocket(socket); }
 int srt_group_data(SRTSOCKET socketgroup, SRT_SOCKGROUPDATA* output, size_t* inoutlen)
 {
     return CUDT::getGroupData(socketgroup, output, inoutlen);
 }
-int srt_group_configure(SRTSOCKET socketgroup, const char* str)
-{
-    return CUDT::configureGroup(socketgroup, str);
-}
 
 SRT_SOCKOPT_CONFIG* srt_create_config()
 {
     return new SRT_SocketOptionObject;
 }
 
-void srt_delete_config(SRT_SOCKOPT_CONFIG* in)
-{
-    delete in;
-}
-
 int srt_config_add(SRT_SOCKOPT_CONFIG* config, SRT_SOCKOPT option, const void* contents, int len)
 {
     if (!config)
@@ -71,9 +60,53 @@ int srt_config_add(SRT_SOCKOPT_CONFIG* config, SRT_SOCKOPT option, const void* c
 
     return 0;
 }
+
+int srt_connect_group(SRTSOCKET group,
+    SRT_SOCKGROUPCONFIG name[], int arraysize)
+{
+    return CUDT::connectLinks(group, name, arraysize);
+}
+
+#else
+
+SRTSOCKET srt_create_group(SRT_GROUP_TYPE) { return SRT_INVALID_SOCK; }
+SRTSOCKET srt_groupof(SRTSOCKET) { return SRT_INVALID_SOCK; }
+int srt_group_data(SRTSOCKET, SRT_SOCKGROUPDATA*, size_t*) { return srt::CUDT::APIError(MJ_NOTSUP, MN_INVAL, 0); }
+SRT_SOCKOPT_CONFIG* srt_create_config() { return NULL; }
+int srt_config_add(SRT_SOCKOPT_CONFIG*, SRT_SOCKOPT, const void*, int) { return srt::CUDT::APIError(MJ_NOTSUP, MN_INVAL, 0); }
+
+int srt_connect_group(SRTSOCKET, SRT_SOCKGROUPCONFIG[], int) { return srt::CUDT::APIError(MJ_NOTSUP, MN_INVAL, 0); }
+
 #endif
 
-// int srt_bind_multicast()
+SRT_SOCKGROUPCONFIG srt_prepare_endpoint(const struct sockaddr* src, const struct sockaddr* dst, int namelen)
+{
+    SRT_SOCKGROUPCONFIG data;
+#if ENABLE_BONDING
+    data.errorcode = SRT_SUCCESS;
+#else
+    data.errorcode = SRT_EINVOP;
+#endif
+    data.id = -1;
+    data.token = -1;
+    data.weight = 0;
+    data.config = NULL;
+    if (src)
+        memcpy(&data.srcaddr, src, namelen);
+    else
+    {
+        memset(&data.srcaddr, 0, sizeof data.srcaddr);
+        // Still set the family according to the target address
+        data.srcaddr.ss_family = dst->sa_family;
+    }
+    memcpy(&data.peeraddr, dst, namelen);
+    return data;
+}
+
+void srt_delete_config(SRT_SOCKOPT_CONFIG* in)
+{
+    delete in;
+}
 
 // Binding and connection management
 int srt_bind(SRTSOCKET u, const struct sockaddr * name, int namelen) { return CUDT::bind(u, name, namelen); }
@@ -90,34 +123,6 @@ int srt_connect_bind(SRTSOCKET u,
     return CUDT::connect(u, source, target, target_len);
 }
 
-#if ENABLE_EXPERIMENTAL_BONDING
-SRT_SOCKGROUPCONFIG srt_prepare_endpoint(const struct sockaddr* src, const struct sockaddr* adr, int namelen)
-{
-    SRT_SOCKGROUPCONFIG data;
-    data.errorcode = SRT_SUCCESS;
-    data.id = -1;
-    data.token = -1;
-    data.weight = 0;
-    data.config = NULL;
-    if (src)
-        memcpy(&data.srcaddr, src, namelen);
-    else
-    {
-        memset(&data.srcaddr, 0, sizeof data.srcaddr);
-        // Still set the family according to the target address
-        data.srcaddr.ss_family = adr->sa_family;
-    }
-    memcpy(&data.peeraddr, adr, namelen);
-    return data;
-}
-
-int srt_connect_group(SRTSOCKET group,
-        SRT_SOCKGROUPCONFIG name [], int arraysize)
-{
-    return CUDT::connectLinks(group, name, arraysize);
-}
-#endif
-
 int srt_rendezvous(SRTSOCKET u, const struct sockaddr* local_name, int local_namelen,
         const struct sockaddr* remote_name, int remote_namelen)
 {
@@ -245,8 +250,8 @@ int srt_getlasterror(int* loc_errno)
 
 const char* srt_strerror(int code, int err)
 {
-    static CUDTException e;
-    e = CUDTException(CodeMajor(code/1000), CodeMinor(code%1000), err);
+    static srt::CUDTException e;
+    e = srt::CUDTException(CodeMajor(code/1000), CodeMinor(code%1000), err);
     return(e.getErrorMessage());
 }
 
@@ -416,4 +421,58 @@ int srt_clock_type()
     return SRT_SYNC_CLOCK;
 }
 
+const char* const srt_rejection_reason_msg [] = {
+    "Unknown or erroneous",
+    "Error in system calls",
+    "Peer rejected connection",
+    "Resource allocation failure",
+    "Rogue peer or incorrect parameters",
+    "Listener's backlog exceeded",
+    "Internal Program Error",
+    "Socket is being closed",
+    "Peer version too old",
+    "Rendezvous-mode cookie collision",
+    "Incorrect passphrase",
+    "Password required or unexpected",
+    "MessageAPI/StreamAPI collision",
+    "Congestion controller type collision",
+    "Packet Filter settings error",
+    "Group settings collision",
+    "Connection timeout"
+};
+
+// Deprecated, available in SRT API.
+extern const char* const srt_rejectreason_msg[] = {
+    srt_rejection_reason_msg[0],
+    srt_rejection_reason_msg[1],
+    srt_rejection_reason_msg[2],
+    srt_rejection_reason_msg[3],
+    srt_rejection_reason_msg[4],
+    srt_rejection_reason_msg[5],
+    srt_rejection_reason_msg[6],
+    srt_rejection_reason_msg[7],
+    srt_rejection_reason_msg[8],
+    srt_rejection_reason_msg[9],
+    srt_rejection_reason_msg[10],
+    srt_rejection_reason_msg[11],
+    srt_rejection_reason_msg[12],
+    srt_rejection_reason_msg[13],
+    srt_rejection_reason_msg[14],
+    srt_rejection_reason_msg[15],
+    srt_rejection_reason_msg[16]
+};
+
+const char* srt_rejectreason_str(int id)
+{
+    if (id >= SRT_REJC_PREDEFINED)
+    {
+        return "Application-defined rejection reason";
+    }
+
+    static const size_t ra_size = Size(srt_rejection_reason_msg);
+    if (size_t(id) >= ra_size)
+        return srt_rejection_reason_msg[0];
+    return srt_rejection_reason_msg[id];
+}
+
 }
