@@ -16,8 +16,7 @@ using namespace srt;
 TEST(CUnitQueue, Increase)
 {
     const int buffer_size_pkts = 4;
-    CUnitQueue unit_queue;
-    unit_queue.init(buffer_size_pkts, 1500, AF_INET);
+    CUnitQueue unit_queue(buffer_size_pkts, 1500);
 
     vector<CUnit*> taken_units;
     for (int i = 0; i < 5 * buffer_size_pkts; ++i)
@@ -37,8 +36,7 @@ TEST(CUnitQueue, Increase)
 TEST(CUnitQueue, IncreaseAndFree)
 {
     const int buffer_size_pkts = 4;
-    CUnitQueue unit_queue;
-    unit_queue.init(buffer_size_pkts, 1500, AF_INET);
+    CUnitQueue unit_queue(buffer_size_pkts, 1500);
 
     CUnit* taken_unit = nullptr;
     for (int i = 0; i < 5 * buffer_size_pkts; ++i)
@@ -62,8 +60,7 @@ TEST(CUnitQueue, IncreaseAndFree)
 TEST(CUnitQueue, IncreaseAndFreeGrouped)
 {
     const int buffer_size_pkts = 4;
-    CUnitQueue unit_queue;
-    unit_queue.init(buffer_size_pkts, 1500, AF_INET);
+    CUnitQueue unit_queue(buffer_size_pkts, 1500);
 
     vector<CUnit*> taken_units;
     for (int i = 0; i < 5 * buffer_size_pkts; ++i)
